rnalysis.filtering.FoldChangeFilter.split\_by\_ref\_table\_attr
===============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.split_by_ref_table_attr